==> mesian-v0.1.1.tar.bz2: mesian-v0.1.1/engine/resource/strings.py <==
# -*- coding: euc-kr -*-
#------------------------------------------------------------------------------ LOG
ERROR = "(**)"
INFO = "(II)"
SUCCESS = "    "

ERROR_NO_ARGV = "You must specify a user@domain."
ERROR_DB_CONNECT_FAILED = "Can not connect to db."
ERROR_NO_MESSAGE = "This is not a proper mail message."
ERROR_UNKNOWN_USER = "There is not a registered user, '%s', so this message was inserted into 'message_unKnown' table."

ERROR_NO_USER_INFO = "There is not a info of user, '%s'"
ERROR_NO_TABLE = "There is no table, '%s'"
ERROR_FAILED_INSERT = "Can not insert this message. '%s'"

SUCCESS_INSERT_MESSAGE = "Successfully inserted message, %s"

ERROR_DELETE_QUEUE_FAILED = "Failed to delete message number '%d' from queue"

# xmlrpc
ERROR_RPC_CONNECT_FAILED = "Can not bind address"
ERROR_RPC_CONNECT_SUCCESS = "Server is located!!"

SUCCESS_SEND_MESSAGE = "sent, from: %s, to: %s, size: %d"
SUCCESS_GET_MESSAGE = "sent, from: %s, to: %s, size: %d"
#---------------------------------------------------------------------------- MESSAGE
DAEMON_USAGE = \
"""Usage : %(name)s [options]
      -h, --help : this message
      -i, --interval : interval to spawn daemon
                       0 means not to run this daemon.
"""
DAEMON_ERROR_INTERVAL_SET = \
"""(***) Set the correct value as /* interval */ %s""" % DAEMON_USAGE

PID_EXISTS = "PID file, '%s' exists. Maybe already started."

DAEMON_START = \
"""--------------------------------------------------------------------------------
 Starting WebMail Server Engine,

                Contact Spike^ekipS <spike@spikeekips.net> for more information.
--------------------------------------------------------------------------------"""

DAEMON_TIMEOUT = \
"""

.....Timeout. Error occured. Check, check and check the environment.
"""

DAEMON_LOAD_MODULE = "\nLoad module : %7s "

MESSAGE_OVERQUOTA = \
"""From: "PostMaster" <postmaster@www.spikeekips.net>
Reply-To: postmaster@www.spikeekips.net
X-Accept-Language: ko-KR
MIME-Version: 1.0
Message-Id: <1054027888@www.spikeekips.net>
To: %(address)s
Subject: Failure Deliver
Content-Type: text/plain; charset=euc-kr
Content-Transfer-Encoding: 8bit


=====================================================================
                              WARNING

            We can not deliver your message to %(address)s,
  because your message is too big, so %(address)s's quota pool is OVERQUOTA.
=====================================================================

=====================================================================
                              ˼մϴ.

           %(address)s 뷮ʰ ޼  ߽ϴ.
=====================================================================

"""

"""
Description
-----------
strings

ChangeLog
---------

Wed Mar 12 04:08:57 KST 2003
- created.

Thu Jun 12 05:04:51 KST 2003
- new stream started.

"""

__author__ =  "Spike^ekipS <spike@spikeekips.net>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "strings.py"


# Mesian is Webmail.
#
# Copyright (C) 2003 Spike^ekipS <spike@spikeekips.net>
#
# Adapted from mesian :
#  Copyright (C) 2003  Spike^ekipS <spike@spikeekips.net>
#
# Contact: mailto:spike@spikeekips.net
# Original site: http://mesian-devel.spikeekips.net/
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
# Spike^ekipS
#	mailto:spike@spikeekips.net
#
# Original page :
#	http://mesian-devel.spikeekips.net/
#
# Original mesian :
#	Spike^ekipS
#	spike@spikeekips.net
#	Haman Korea

==> mesian-v0.1.2.tar.bz2: mesian-v0.1.2/engine/resource/strings.py <==
# -*- coding: euc-kr -*-
#------------------------------------------------------------------------------ LOG
ERROR = "(**)"
INFO = "(II)"
SUCCESS = "    "

ERROR_NO_ARGV = "You must specify a user@domain."
ERROR_DB_CONNECT_FAILED = "Can not connect to db."
ERROR_NO_MESSAGE = "This is not a proper mail message."
ERROR_UNKNOWN_USER = "There is not a registered user, '%s', so this message was inserted into 'message_unKnown' table."

ERROR_NO_USER_INFO = "There is not a info of user, '%s'"
ERROR_NO_TABLE = "There is no table, '%s'"
ERROR_FAILED_INSERT = "Can not insert this message. '%s'"

SUCCESS_INSERT_MESSAGE = "Successfully inserted message, %s"

ERROR_DELETE_QUEUE_FAILED = "Failed to delete message number '%d' from queue"

# xmlrpc
ERROR_RPC_CONNECT_FAILED = "Can not bind address"
ERROR_RPC_CONNECT_SUCCESS = "Server is located!!"

SUCCESS_SEND_MESSAGE = "sent, from: %s, to: %s, size: %d"
SUCCESS_GET_MESSAGE = "sent, from: %s, to: %s, size: %d"
#---------------------------------------------------------------------------- MESSAGE
DAEMON_USAGE = \
"""Usage : %(name)s [options]
      -h, --help : this message
      -i, --interval : interval to spawn daemon
                       0 means not to run this daemon.
"""
DAEMON_ERROR_INTERVAL_SET = \
"""(***) Set the correct value as /* interval */ %s""" % DAEMON_USAGE

PID_EXISTS = "PID file, '%s' exists. Maybe already started."

DAEMON_START = \
"""--------------------------------------------------------------------------------
 Starting WebMail Server Engine,

                Contact Spike^ekipS <spike@spikeekips.net> for more information.
--------------------------------------------------------------------------------"""

DAEMON_TIMEOUT = \
"""

.....Timeout. Error occured. Check, check and check the environment.
"""

DAEMON_LOAD_MODULE = "\nLoad module : %7s "

MESSAGE_OVERQUOTA = \
"""From: "PostMaster" <postmaster@mesian.spikeekips.net>
Reply-To: postmaster@www.spikeekips.net
X-Accept-Language: ko-KR
MIME-Version: 1.0
Message-Id: <1054027888@mesian.spikeekips.net>
To: %(address)s
Subject: Failure Deliver
Content-Type: text/plain; charset=euc-kr
Content-Transfer-Encoding: 8bit


=====================================================================
                              WARNING

            We can not deliver your message to %(address)s,
  because your message is too big, so %(address)s's quota pool is OVERQUOTA.
=====================================================================

=====================================================================
                              ˼մϴ.

           %(address)s 뷮ʰ ޼  ߽ϴ.
=====================================================================

"""

"""
Description
-----------
strings

ChangeLog
---------

Wed Mar 12 04:08:57 KST 2003
- created.

Thu Jun 12 05:04:51 KST 2003
- new stream started.

"""

__author__ =  "Spike^ekipS <spike@spikeekips.net>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "strings.py"
